import { OkunaOpts } from "./typings";
import { RequestStrategy } from './utils/requestStrategies';
import { AuthAPI } from './api/auth';
import { CategoriesAPI } from './api/categories';
import { CirclesAPI } from './api/circles';
import { CommunitiesAPI } from './api/communities';
import { ConnectionsAPI } from './api/connections';
import { DevicesAPI } from './api/devices';
import { EmojisAPI } from './api/emojis';
import { FollowsAPI } from './api/follows';
import { HealthAPI } from './api/health';
import { ListsAPI } from './api/lists';
import { ModerationAPI } from './api/moderation';
import { NotificationsAPI } from './api/notifications';
import { PostsAPI } from './api/posts';
import { UserInvitesAPI } from './api/userInvites';
/**
 * @api public
 */
declare class Client {
    /**
     * JavaScript API bindings for the Okuna social network
     *
     * @param {OkunaOpts} opts
     */
    readonly apiUrl: string;
    authToken: string | null;
    readonly magicHeaderName: string | null | undefined;
    readonly magicHeaderValue: string | null | undefined;
    readonly requestStrategy: string | RequestStrategy;
    constructor(opts?: OkunaOpts);
    /**
     * _buildMagicHeader() - Builds a magic header to add to the request headers
     * @param {string | null | undefined} name - the name of the magic header
     * @param {string | null | undefined} value - the value of the magic header
     * @returns {object} an object containing the provided data
     */
    _buildMagicHeader(name: string | null | undefined, value: string | null | undefined): {
        name: string | null | undefined;
        value: string | null | undefined;
    };
    /**
     * updateAuthToken() - Updates the authorization token of the current Client instance
     * @param {string} token - the new authorization token
     */
    updateAuthToken(token: string): void;
    /**
     * auth()
     * @returns { AuthAPI } - AuthAPI instance
     */
    auth(): AuthAPI;
    /**
     * categories()
     * @returns {CategoriesAPI} - CategoriesAPI instance
     */
    categories(): CategoriesAPI;
    /**
     * circles()
     * @returns {CirclesAPI} - CirclesAPI instance
     */
    circles(): CirclesAPI;
    /**
     * communities()
     * @returns {CommunitiesAPI} - CommunitiesAPI instance
     */
    communities(): CommunitiesAPI;
    /**
     * connections()
     * @returns {ConnectionsAPI} - ConnectionsAPI instance
     */
    connections(): ConnectionsAPI;
    /**
     * devices()
     * @returns {DevicesAPI} - DevicesAPI instance
     */
    devices(): DevicesAPI;
    /**
     * emojis()
     * @returns {EmojisAPI} - EmojisAPI instance
     */
    emojis(): EmojisAPI;
    /**
     * follows()
     * @returns {FollowsAPI} - FollowsAPI instance
     */
    follows(): FollowsAPI;
    /**
     * health()
     * @returns {HealthAPI} - HealthAPI instance
     */
    health(): HealthAPI;
    /**
     * lists()
     * @returns {ListsAPI} - ListsAPI instance
     */
    lists(): ListsAPI;
    /**
     * moderation()
     * @returns {ModerationAPI} - ModerationAPI instance
     */
    moderation(): ModerationAPI;
    /**
     * notifications()
     * @returns {NotificationsAPI} - NotificationsAPI instance
     */
    notifications(): NotificationsAPI;
    /**
     * posts()
     * @returns {PostsAPI} - PostsAPI instance
     */
    posts(): PostsAPI;
    /**
     * userInvites()
     * @returns {UserInvitesAPI} - UserInvitesAPI instance
     */
    userInvites(): UserInvitesAPI;
}
export { Client, RequestStrategy };
