"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var requestStrategies_1 = require("./utils/requestStrategies");
exports.RequestStrategy = requestStrategies_1.RequestStrategy;
var auth_1 = require("./api/auth");
var categories_1 = require("./api/categories");
var circles_1 = require("./api/circles");
var communities_1 = require("./api/communities");
var connections_1 = require("./api/connections");
var devices_1 = require("./api/devices");
var emojis_1 = require("./api/emojis");
var follows_1 = require("./api/follows");
var health_1 = require("./api/health");
var lists_1 = require("./api/lists");
var moderation_1 = require("./api/moderation");
var notifications_1 = require("./api/notifications");
var posts_1 = require("./api/posts");
var userInvites_1 = require("./api/userInvites");
/**
 * @api public
 */
var Client = /** @class */ (function () {
    function Client(opts) {
        if (opts === void 0) { opts = {}; }
        this.apiUrl = opts.apiUrl || 'https://api.openbook.social';
        this.authToken = opts.authToken || null;
        var magicHeader = this._buildMagicHeader(opts.magicHeaderName, opts.magicHeaderValue);
        this.magicHeaderName = magicHeader.name;
        this.magicHeaderValue = magicHeader.value;
        this.requestStrategy = opts.requestStrategy || 'fetch';
    }
    /**
     * _buildMagicHeader() - Builds a magic header to add to the request headers
     * @param {string | null | undefined} name - the name of the magic header
     * @param {string | null | undefined} value - the value of the magic header
     * @returns {object} an object containing the provided data
     */
    Client.prototype._buildMagicHeader = function (name, value) {
        if (name === null || value === null) {
            return {
                name: name,
                value: value
            };
        }
        return {
            name: name || 'X-JESUS-TAKE-THE-WHEEL',
            value: value || 'jesusCantReallyDriveTho'
        };
    };
    /**
     * updateAuthToken() - Updates the authorization token of the current Client instance
     * @param {string} token - the new authorization token
     */
    Client.prototype.updateAuthToken = function (token) {
        this.authToken = token;
    };
    /**
     * auth()
     * @returns { AuthAPI } - AuthAPI instance
     */
    Client.prototype.auth = function () {
        return new auth_1.AuthAPI({ okuna: this, endpoint: '/api/auth' });
    };
    /**
     * categories()
     * @returns {CategoriesAPI} - CategoriesAPI instance
     */
    Client.prototype.categories = function () {
        return new categories_1.CategoriesAPI({ okuna: this, endpoint: '/api/categories' });
    };
    /**
     * circles()
     * @returns {CirclesAPI} - CirclesAPI instance
     */
    Client.prototype.circles = function () {
        return new circles_1.CirclesAPI({ okuna: this, endpoint: '/api/circles' });
    };
    /**
     * communities()
     * @returns {CommunitiesAPI} - CommunitiesAPI instance
     */
    Client.prototype.communities = function () {
        return new communities_1.CommunitiesAPI({ okuna: this, endpoint: '/api/communities' });
    };
    /**
     * connections()
     * @returns {ConnectionsAPI} - ConnectionsAPI instance
     */
    Client.prototype.connections = function () {
        return new connections_1.ConnectionsAPI({ okuna: this, endpoint: '/api/connections' });
    };
    /**
     * devices()
     * @returns {DevicesAPI} - DevicesAPI instance
     */
    Client.prototype.devices = function () {
        return new devices_1.DevicesAPI({ okuna: this, endpoint: '/api/devices' });
    };
    /**
     * emojis()
     * @returns {EmojisAPI} - EmojisAPI instance
     */
    Client.prototype.emojis = function () {
        return new emojis_1.EmojisAPI({ okuna: this, endpoint: '/api/emojis' });
    };
    /**
     * follows()
     * @returns {FollowsAPI} - FollowsAPI instance
     */
    Client.prototype.follows = function () {
        return new follows_1.FollowsAPI({ okuna: this, endpoint: '/api/follows' });
    };
    /**
     * health()
     * @returns {HealthAPI} - HealthAPI instance
     */
    Client.prototype.health = function () {
        return new health_1.HealthAPI({ okuna: this, endpoint: '/api/health' });
    };
    /**
     * lists()
     * @returns {ListsAPI} - ListsAPI instance
     */
    Client.prototype.lists = function () {
        return new lists_1.ListsAPI({ okuna: this, endpoint: '/api/lists' });
    };
    /**
     * moderation()
     * @returns {ModerationAPI} - ModerationAPI instance
     */
    Client.prototype.moderation = function () {
        return new moderation_1.ModerationAPI({ okuna: this, endpoint: '/api/moderation' });
    };
    /**
     * notifications()
     * @returns {NotificationsAPI} - NotificationsAPI instance
     */
    Client.prototype.notifications = function () {
        return new notifications_1.NotificationsAPI({ okuna: this, endpoint: '/api/notifications' });
    };
    /**
     * posts()
     * @returns {PostsAPI} - PostsAPI instance
     */
    Client.prototype.posts = function () {
        return new posts_1.PostsAPI({ okuna: this, endpoint: '/api/posts' });
    };
    /**
     * userInvites()
     * @returns {UserInvitesAPI} - UserInvitesAPI instance
     */
    Client.prototype.userInvites = function () {
        return new userInvites_1.UserInvitesAPI({ okuna: this, endpoint: '/api/invites' });
    };
    return Client;
}());
exports.Client = Client;
