import { APIRequest } from "../utils/APIRequest";
import { RequestOpts } from '../typings';
import { ICreateCircle, IUpdateCircle } from '../typings/api/circles';
/**
 * @api public
 * CirclesAPI - Provides methods to interact with the Circles API
 */
declare class CirclesAPI extends APIRequest {
    constructor(opts: RequestOpts);
    /**
     * `GET /api/circles/` - promises to retrieve all circles
     * @returns - an array of circles
     */
    getCircles(): Promise<any>;
    /**
     * `PUT /api/circles/` - promises to create a new circle
     * @param {ICreateCircle} opts - The circle's properties
     * @returns - the circle
     */
    createCircle(opts: ICreateCircle): Promise<any>;
    /**
     * `PATCH /api/circles/:id/` - promises to update a circle
     * @param {number} id - The ID of the circle
     * @param {IUpdateCircle} - The circle's new properties
     * @returns - the updated circle
     */
    updateCircle(id: number, opts: IUpdateCircle): Promise<any>;
    /**
     * `GET /api/circles/:id/` - promises to get a circle
     * @param {number} id - The ID of the circle
     * @returns - the requested circle
     */
    getCircle(id: number): Promise<any>;
    /**
     * `DELETE /api/circles/:id/` - promises to delete a circle
     * @param {number} id - The ID of the circle
     */
    deleteCircle(id: number): Promise<any>;
    /**
     * `POST /api/circles/name-check/` - promises to check if a circle name is available
     * @param {string} name - The desired name
     */
    checkNameIsAvailable(name: string): Promise<any>;
}
export { CirclesAPI };
