"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var APIRequest_1 = require("../utils/APIRequest");
/**
 * @api public
 * CirclesAPI - Provides methods to interact with the Circles API
 */
var CirclesAPI = /** @class */ (function (_super) {
    tslib_1.__extends(CirclesAPI, _super);
    function CirclesAPI(opts) {
        return _super.call(this, opts) || this;
    }
    /**
     * `GET /api/circles/` - promises to retrieve all circles
     * @returns - an array of circles
     */
    CirclesAPI.prototype.getCircles = function () {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                return [2 /*return*/, this.get()];
            });
        });
    };
    /**
     * `PUT /api/circles/` - promises to create a new circle
     * @param {ICreateCircle} opts - The circle's properties
     * @returns - the circle
     */
    CirclesAPI.prototype.createCircle = function (opts) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                return [2 /*return*/, this.put(opts)];
            });
        });
    };
    /**
     * `PATCH /api/circles/:id/` - promises to update a circle
     * @param {number} id - The ID of the circle
     * @param {IUpdateCircle} - The circle's new properties
     * @returns - the updated circle
     */
    CirclesAPI.prototype.updateCircle = function (id, opts) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push(id.toString());
                return [2 /*return*/, this.patch(opts)];
            });
        });
    };
    /**
     * `GET /api/circles/:id/` - promises to get a circle
     * @param {number} id - The ID of the circle
     * @returns - the requested circle
     */
    CirclesAPI.prototype.getCircle = function (id) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push(id.toString());
                return [2 /*return*/, this.get()];
            });
        });
    };
    /**
     * `DELETE /api/circles/:id/` - promises to delete a circle
     * @param {number} id - The ID of the circle
     */
    CirclesAPI.prototype.deleteCircle = function (id) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push(id.toString());
                return [2 /*return*/, this.delete()];
            });
        });
    };
    /**
     * `POST /api/circles/name-check/` - promises to check if a circle name is available
     * @param {string} name - The desired name
     */
    CirclesAPI.prototype.checkNameIsAvailable = function (name) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push('name-check');
                return [2 /*return*/, this.post({ name: name })];
            });
        });
    };
    return CirclesAPI;
}(APIRequest_1.APIRequest));
exports.CirclesAPI = CirclesAPI;
