import { APIRequest } from "../utils/APIRequest";
import { RequestOpts, LimitationParamsWithAuthenticationCheck, LimitationParams } from '../typings';
import { ICreatePost } from '../typings/api/posts';
import { ICreateCommunity, IUpdateCommunity, IGetMembersForCommunity, ISearchMembers, IGetJoinedCommunities, ISearchJoinedCommunities, IGetFavoriteCommunities, IGetAdministratedCommunities, IReportCommunity } from '../typings/api/communities';
import { IGetGlobalModeratedObjects } from '../typings/api/moderation';
import { IFileObjectOpts } from '../utils/FileObject';
declare class CommunitiesAPI extends APIRequest {
    constructor(opts: RequestOpts);
    checkNameIsAvailable(name: string): Promise<any>;
    getTrendingCommunities(authenticatedRequest?: boolean, category?: string | null): Promise<any>;
    createPost(communityName: string, opts: ICreatePost): Promise<any>;
    getPostsForCommunity(name: string, opts: LimitationParamsWithAuthenticationCheck): Promise<any>;
    getClosedPostsForCommunity(name: string, opts: LimitationParamsWithAuthenticationCheck): Promise<any>;
    getCommunitiesWithQuery(query: string, authenticatedRequest?: boolean): Promise<any>;
    getCommunity(name: string, authenticatedRequest?: boolean): Promise<any>;
    createCommunity(opts: ICreateCommunity): Promise<any>;
    updateCommunity(name: string, opts: IUpdateCommunity): Promise<any>;
    updateCommunityAvatar(name: string, avatar: IFileObjectOpts): Promise<any>;
    deleteCommunityAvatar(name: string): Promise<any>;
    updateCommunityCover(name: string, cover: IFileObjectOpts): Promise<any>;
    deleteCommunityCover(name: string): Promise<any>;
    deleteCommunity(name: string): Promise<any>;
    getMembersForCommunity(name: string, opts: IGetMembersForCommunity): Promise<any>;
    searchMembers(name: string, opts: ISearchMembers): Promise<any>;
    inviteUserToCommunity(communityName: string, username: string): Promise<any>;
    uninviteUserToCommunity(communityName: string, username: string): Promise<any>;
    getJoinedCommunities(opts: IGetJoinedCommunities): Promise<any>;
    searchJoinedCommunities(opts: ISearchJoinedCommunities): Promise<any>;
    joinCommunity(name: string): Promise<any>;
    leaveCommunity(name: string): Promise<any>;
    getModeratorsForCommunity(name: string, opts: LimitationParams): Promise<any>;
    searchModerators(communityName: string, query: string): Promise<any>;
    addCommunityModerator(communityName: string, username: string): Promise<any>;
    removeCommunityModerator(communityName: string, username: string): Promise<any>;
    getAdministratorsForCommunity(name: string, opts: LimitationParams): Promise<any>;
    searchAdministrators(communityName: string, query: string): Promise<any>;
    addCommunityAdministrator(communityName: string, username: string): Promise<any>;
    removeCommunityAdministrator(communityName: string, username: string): Promise<any>;
    getBannedUsersForCommunity(name: string, opts: LimitationParams): Promise<any>;
    searchBannedUsers(communityName: string, query: string): Promise<any>;
    banCommunityUser(communityName: string, username: string): Promise<any>;
    unbanCommunityUser(communityName: string, username: string): Promise<any>;
    getFavoriteCommunities(opts: IGetFavoriteCommunities): Promise<any>;
    favoriteCommunity(communityName: string): Promise<any>;
    unfavoriteCommunity(communityName: string): Promise<any>;
    getAdministratedCommunities(opts: IGetAdministratedCommunities): Promise<any>;
    getModeratedCommunities(opts: IGetAdministratedCommunities): Promise<any>;
    reportCommunity(opts: IReportCommunity): Promise<any>;
    getModeratedObjects(communityName: string, opts: IGetGlobalModeratedObjects): Promise<any>;
}
export { CommunitiesAPI };
