"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var APIRequest_1 = require("../utils/APIRequest");
var FileObject_1 = require("../utils/FileObject");
var CommunitiesAPI = /** @class */ (function (_super) {
    tslib_1.__extends(CommunitiesAPI, _super);
    function CommunitiesAPI(opts) {
        return _super.call(this, opts) || this;
    }
    CommunitiesAPI.prototype.checkNameIsAvailable = function (name) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push('name-check');
                return [2 /*return*/, this.post({ name: name })];
            });
        });
    };
    CommunitiesAPI.prototype.getTrendingCommunities = function (authenticatedRequest, category) {
        if (authenticatedRequest === void 0) { authenticatedRequest = true; }
        if (category === void 0) { category = null; }
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push('trending');
                this.requiresToken = authenticatedRequest;
                if (category) {
                    this._params.category = category;
                }
                return [2 /*return*/, this.get()];
            });
        });
    };
    CommunitiesAPI.prototype.createPost = function (communityName, opts) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            var payload;
            return tslib_1.__generator(this, function (_a) {
                this._paths.push(encodeURIComponent(communityName), 'posts');
                payload = {};
                if (opts.image) {
                    payload['image'] = new FileObject_1.FileObject(opts.image);
                }
                if (opts.video) {
                    payload['video'] = new FileObject_1.FileObject(opts.video);
                }
                if (opts.text) {
                    payload['text'] = opts.text;
                }
                if (opts.circleIds && opts.circleIds.length) {
                    payload['circle_id'] = opts.circleIds.join(',');
                }
                return [2 /*return*/, this.putFormdata(payload)];
            });
        });
    };
    CommunitiesAPI.prototype.getPostsForCommunity = function (name, opts) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push(encodeURIComponent(name), 'posts');
                this.requiresToken = opts.authenticatedRequest || opts.authenticatedRequest === undefined;
                if (opts.count !== undefined) {
                    this._params.count = opts.count;
                }
                if (opts.maxId !== undefined) {
                    this._params.max_id = opts.maxId;
                }
                return [2 /*return*/, this.get()];
            });
        });
    };
    CommunitiesAPI.prototype.getClosedPostsForCommunity = function (name, opts) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push(encodeURIComponent(name), 'posts', 'closed');
                this.requiresToken = opts.authenticatedRequest || opts.authenticatedRequest === undefined;
                if (opts.count !== undefined) {
                    this._params.count = opts.count;
                }
                if (opts.maxId !== undefined) {
                    this._params.max_id = opts.maxId;
                }
                return [2 /*return*/, this.get()];
            });
        });
    };
    CommunitiesAPI.prototype.getCommunitiesWithQuery = function (query, authenticatedRequest) {
        if (authenticatedRequest === void 0) { authenticatedRequest = true; }
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push('search');
                this._params.query = query;
                this.requiresToken = authenticatedRequest;
                return [2 /*return*/, this.get()];
            });
        });
    };
    CommunitiesAPI.prototype.getCommunity = function (name, authenticatedRequest) {
        if (authenticatedRequest === void 0) { authenticatedRequest = true; }
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push(encodeURIComponent(name));
                this.requiresToken = authenticatedRequest;
                return [2 /*return*/, this.get()];
            });
        });
    };
    CommunitiesAPI.prototype.createCommunity = function (opts) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            var payload;
            return tslib_1.__generator(this, function (_a) {
                payload = {
                    name: opts.name,
                    title: opts.title,
                    categories: opts.categories.join(','),
                    type: opts.type
                };
                if (opts.avatar) {
                    payload.avatar = new FileObject_1.FileObject(opts.avatar);
                }
                if (opts.cover) {
                    payload.cover = new FileObject_1.FileObject(opts.cover);
                }
                if (opts.color) {
                    payload.color = opts.color;
                }
                if (opts.rules) {
                    payload.rules = opts.rules;
                }
                if (opts.description) {
                    payload.description = opts.description;
                }
                if (opts.userAdjective) {
                    payload.user_adjective = opts.userAdjective;
                }
                if (opts.usersAdjective) {
                    payload.users_adjective = opts.usersAdjective;
                }
                if (opts.invitesEnabled !== undefined) {
                    payload.invites_enabled = opts.invitesEnabled;
                }
                return [2 /*return*/, this.putFormdata(payload)];
            });
        });
    };
    CommunitiesAPI.prototype.updateCommunity = function (name, opts) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            var payload;
            return tslib_1.__generator(this, function (_a) {
                this._paths.push(encodeURIComponent(name));
                payload = {};
                if (opts.name) {
                    payload.name = opts.name;
                }
                if (opts.title) {
                    payload.title = opts.title;
                }
                if (opts.categories && opts.categories.length) {
                    payload.categories = opts.categories.join(',');
                }
                if (opts.type) {
                    payload.type = opts.type;
                }
                if (opts.color) {
                    payload.color = opts.color;
                }
                if (opts.rules) {
                    payload.rules = opts.rules;
                }
                if (opts.description) {
                    payload.description = opts.description;
                }
                if (opts.userAdjective) {
                    payload.user_adjective = opts.userAdjective;
                }
                if (opts.usersAdjective) {
                    payload.users_adjective = opts.usersAdjective;
                }
                if (opts.invitesEnabled !== undefined) {
                    payload.invites_enabled = opts.invitesEnabled;
                }
                return [2 /*return*/, this.patchFormdata(payload)];
            });
        });
    };
    CommunitiesAPI.prototype.updateCommunityAvatar = function (name, avatar) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                if (!avatar.name) {
                    throw new Error('Invalid community avatar!');
                }
                this._paths.push(encodeURIComponent(name), 'avatar');
                return [2 /*return*/, this.putFormdata({ avatar: new FileObject_1.FileObject(avatar) })];
            });
        });
    };
    CommunitiesAPI.prototype.deleteCommunityAvatar = function (name) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push(encodeURIComponent(name), 'avatar');
                return [2 /*return*/, this.delete()];
            });
        });
    };
    CommunitiesAPI.prototype.updateCommunityCover = function (name, cover) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                if (!cover.name) {
                    throw new Error('Invalid community cover!');
                }
                this._paths.push(encodeURIComponent(name), 'cover');
                return [2 /*return*/, this.putFormdata({ cover: new FileObject_1.FileObject(cover) })];
            });
        });
    };
    CommunitiesAPI.prototype.deleteCommunityCover = function (name) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push(encodeURIComponent(name), 'cover');
                return [2 /*return*/, this.delete()];
            });
        });
    };
    CommunitiesAPI.prototype.deleteCommunity = function (name) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push(encodeURIComponent(name));
                return [2 /*return*/, this.delete()];
            });
        });
    };
    CommunitiesAPI.prototype.getMembersForCommunity = function (name, opts) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push(encodeURIComponent(name), 'members');
                if (opts.count !== undefined) {
                    this._params.count = opts.count;
                }
                if (opts.maxId !== undefined) {
                    this._params.max_id = opts.maxId;
                }
                if (opts.exclude && opts.exclude.length) {
                    this._params.exclude = opts.exclude.join(',');
                }
                return [2 /*return*/, this.get()];
            });
        });
    };
    CommunitiesAPI.prototype.searchMembers = function (name, opts) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push(encodeURIComponent(name), 'members', 'search');
                this._params.query = opts.query;
                if (opts.count !== undefined) {
                    this._params.count = opts.count;
                }
                if (opts.maxId !== undefined) {
                    this._params.max_id = opts.maxId;
                }
                if (opts.exclude && opts.exclude.length) {
                    this._params.exclude = opts.exclude.join(',');
                }
                return [2 /*return*/, this.get()];
            });
        });
    };
    CommunitiesAPI.prototype.inviteUserToCommunity = function (communityName, username) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push(encodeURIComponent(communityName), 'invite');
                return [2 /*return*/, this.post({ username: username })];
            });
        });
    };
    CommunitiesAPI.prototype.uninviteUserToCommunity = function (communityName, username) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push(encodeURIComponent(communityName), 'uninvite');
                return [2 /*return*/, this.post({ username: username })];
            });
        });
    };
    CommunitiesAPI.prototype.getJoinedCommunities = function (opts) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push('joined');
                this.requiresToken = opts.authenticatedRequest || opts.authenticatedRequest === undefined;
                if (opts.offset !== undefined) {
                    this._params.offset = opts.offset;
                }
                return [2 /*return*/, this.get()];
            });
        });
    };
    CommunitiesAPI.prototype.searchJoinedCommunities = function (opts) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push('joined', 'search');
                this._params.query = opts.query;
                if (opts.count !== undefined) {
                    this._params.offset = opts.count;
                }
                return [2 /*return*/, this.get()];
            });
        });
    };
    CommunitiesAPI.prototype.joinCommunity = function (name) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push(encodeURIComponent(name), 'members', 'join');
                return [2 /*return*/, this.post({})];
            });
        });
    };
    CommunitiesAPI.prototype.leaveCommunity = function (name) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push(encodeURIComponent(name), 'members', 'leave');
                return [2 /*return*/, this.post({})];
            });
        });
    };
    CommunitiesAPI.prototype.getModeratorsForCommunity = function (name, opts) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push(encodeURIComponent(name), 'moderators');
                if (opts.count !== undefined) {
                    this._params.count = opts.count;
                }
                if (opts.maxId !== undefined) {
                    this._params.max_id = opts.maxId;
                }
                return [2 /*return*/, this.get()];
            });
        });
    };
    CommunitiesAPI.prototype.searchModerators = function (communityName, query) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push(encodeURIComponent(communityName), 'moderators', 'search');
                this._params.query = query;
                return [2 /*return*/, this.get()];
            });
        });
    };
    CommunitiesAPI.prototype.addCommunityModerator = function (communityName, username) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push(encodeURIComponent(communityName), 'moderators');
                return [2 /*return*/, this.put({ username: username })];
            });
        });
    };
    CommunitiesAPI.prototype.removeCommunityModerator = function (communityName, username) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push(encodeURIComponent(communityName), 'moderators', encodeURIComponent(username));
                return [2 /*return*/, this.delete()];
            });
        });
    };
    CommunitiesAPI.prototype.getAdministratorsForCommunity = function (name, opts) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push(encodeURIComponent(name), 'administrators');
                if (opts.count !== undefined) {
                    this._params.count = opts.count;
                }
                if (opts.maxId !== undefined) {
                    this._params.max_id = opts.maxId;
                }
                return [2 /*return*/, this.get()];
            });
        });
    };
    CommunitiesAPI.prototype.searchAdministrators = function (communityName, query) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push(encodeURIComponent(communityName), 'administrators', 'search');
                this._params.query = query;
                return [2 /*return*/, this.get()];
            });
        });
    };
    CommunitiesAPI.prototype.addCommunityAdministrator = function (communityName, username) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push(encodeURIComponent(communityName), 'administrators');
                return [2 /*return*/, this.put({ username: username })];
            });
        });
    };
    CommunitiesAPI.prototype.removeCommunityAdministrator = function (communityName, username) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push(encodeURIComponent(communityName), 'administrators', encodeURIComponent(username));
                return [2 /*return*/, this.delete()];
            });
        });
    };
    CommunitiesAPI.prototype.getBannedUsersForCommunity = function (name, opts) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push(encodeURIComponent(name), 'banned-users');
                if (opts.count !== undefined) {
                    this._params.count = opts.count;
                }
                if (opts.maxId !== undefined) {
                    this._params.max_id = opts.maxId;
                }
                return [2 /*return*/, this.get()];
            });
        });
    };
    CommunitiesAPI.prototype.searchBannedUsers = function (communityName, query) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push(encodeURIComponent(communityName), 'banned-users', 'search');
                this._params.query = query;
                return [2 /*return*/, this.get()];
            });
        });
    };
    CommunitiesAPI.prototype.banCommunityUser = function (communityName, username) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push(encodeURIComponent(communityName), 'banned-users', 'ban');
                return [2 /*return*/, this.post({ username: username })];
            });
        });
    };
    CommunitiesAPI.prototype.unbanCommunityUser = function (communityName, username) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push(encodeURIComponent(communityName), 'banned-users', 'unban');
                return [2 /*return*/, this.post({ username: username })];
            });
        });
    };
    CommunitiesAPI.prototype.getFavoriteCommunities = function (opts) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push('favorites');
                this.requiresToken = opts.authenticatedRequest || opts.authenticatedRequest === undefined;
                if (opts.offset !== undefined) {
                    this._params.offset = opts.offset;
                }
                return [2 /*return*/, this.get()];
            });
        });
    };
    CommunitiesAPI.prototype.favoriteCommunity = function (communityName) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push(encodeURIComponent(communityName), 'favorite');
                return [2 /*return*/, this.put({})];
            });
        });
    };
    CommunitiesAPI.prototype.unfavoriteCommunity = function (communityName) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push(encodeURIComponent(communityName), 'favorite');
                return [2 /*return*/, this.delete()];
            });
        });
    };
    CommunitiesAPI.prototype.getAdministratedCommunities = function (opts) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push('administrated');
                this.requiresToken = opts.authenticatedRequest || opts.authenticatedRequest === undefined;
                if (opts.offset !== undefined) {
                    this._params.offset = opts.offset;
                }
                return [2 /*return*/, this.get()];
            });
        });
    };
    CommunitiesAPI.prototype.getModeratedCommunities = function (opts) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push('moderated');
                this.requiresToken = opts.authenticatedRequest || opts.authenticatedRequest === undefined;
                if (opts.offset !== undefined) {
                    this._params.offset = opts.offset;
                }
                return [2 /*return*/, this.get()];
            });
        });
    };
    CommunitiesAPI.prototype.reportCommunity = function (opts) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            var body;
            return tslib_1.__generator(this, function (_a) {
                this._paths.push(encodeURIComponent(opts.communityName), 'report');
                body = {
                    category_id: opts.moderationCategoryId.toString()
                };
                if (opts.description) {
                    body.description = opts.description;
                }
                return [2 /*return*/, this.post(body)];
            });
        });
    };
    CommunitiesAPI.prototype.getModeratedObjects = function (communityName, opts) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push(encodeURIComponent(communityName), 'moderated-objects');
                if (opts.count !== undefined) {
                    this._params.count = opts.count;
                }
                if (opts.maxId !== undefined) {
                    this._params.max_id = opts.maxId;
                }
                if (opts.statuses && opts.statuses.length) {
                    this._params.statuses = opts.statuses.join(',');
                }
                if (opts.types && opts.types.length) {
                    this._params.types = opts.types.join(',');
                }
                if (opts.verified !== undefined) {
                    this._params.verified = opts.verified;
                }
                return [2 /*return*/, this.get()];
            });
        });
    };
    return CommunitiesAPI;
}(APIRequest_1.APIRequest));
exports.CommunitiesAPI = CommunitiesAPI;
