"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var APIRequest_1 = require("../utils/APIRequest");
/**
 * @api public
 * ConnectionsAPI - Provides methods to interact with the Connections API
 */
var ConnectionsAPI = /** @class */ (function (_super) {
    tslib_1.__extends(ConnectionsAPI, _super);
    function ConnectionsAPI(opts) {
        return _super.call(this, opts) || this;
    }
    /**
     * `POST /api/connections/connect/` - Promises to connect to a user
     * @param {IUserConnection} opts
     */
    ConnectionsAPI.prototype.connect = function (opts) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            var body;
            return tslib_1.__generator(this, function (_a) {
                this._paths.push('connect');
                body = {
                    username: opts.username
                };
                if (opts.circleIds && opts.circleIds.length) {
                    body.circles_ids = opts.circleIds;
                }
                return [2 /*return*/, this.post(body)];
            });
        });
    };
    /**
     * `POST /api/connections/confirm/` - Promises to confirm a user connection
     * @param {IUserConnection} opts
     */
    ConnectionsAPI.prototype.confirm = function (opts) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            var body;
            return tslib_1.__generator(this, function (_a) {
                this._paths.push('confirm');
                body = {
                    username: opts.username
                };
                if (opts.circleIds && opts.circleIds.length) {
                    body.circles_ids = opts.circleIds;
                }
                return [2 /*return*/, this.post(body)];
            });
        });
    };
    /**
     * `POST /api/connections/update/` - Promises to update a connection
     * @param {IUserConnection} opts
     */
    ConnectionsAPI.prototype.update = function (opts) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            var body;
            return tslib_1.__generator(this, function (_a) {
                body = {
                    username: opts.username
                };
                if (opts.circleIds && opts.circleIds.length) {
                    body.circles_ids = opts.circleIds;
                }
                return [2 /*return*/, this.post(body)];
            });
        });
    };
    /**
     * `POST /api/connections/disconnect/` - Promises to disconnect from a user
     * @param {string} username - The user to disconnect from
     */
    ConnectionsAPI.prototype.disconnect = function (username) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push('disconnect');
                return [2 /*return*/, this.post({ username: username })];
            });
        });
    };
    return ConnectionsAPI;
}(APIRequest_1.APIRequest));
exports.ConnectionsAPI = ConnectionsAPI;
