"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var APIRequest_1 = require("../utils/APIRequest");
/**
 * @api public
 * DevicesAPI - Provides methods to interact with the Devices API
 */
var DevicesAPI = /** @class */ (function (_super) {
    tslib_1.__extends(DevicesAPI, _super);
    function DevicesAPI(opts) {
        return _super.call(this, opts) || this;
    }
    /**
     * `GET /api/devices/` - Promises to retrieve an array of devices
     */
    DevicesAPI.prototype.getDevices = function () {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                return [2 /*return*/, this.get()];
            });
        });
    };
    /**
     * `DELETE /api/devices/` - Promises to delete the devices
     */
    DevicesAPI.prototype.deleteDevices = function () {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                return [2 /*return*/, this.delete()];
            });
        });
    };
    /**
     * `GET /api/devices/uuid/` - Promises to get a device based on its UUID
     * @param {string} uuid - The universally unique identifier of the device
     */
    DevicesAPI.prototype.getDevice = function (uuid) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push(encodeURIComponent(uuid));
                return [2 /*return*/, this.get()];
            });
        });
    };
    /**
     * `PUT /api/devices/` - Promises to create a device
     * @param {string} uuid - The universally unique identifier of the device
     * @param {string} name - The name of the device
     */
    DevicesAPI.prototype.createDevice = function (uuid, name) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                return [2 /*return*/, this.put({ uuid: uuid, name: name })];
            });
        });
    };
    /**
     * `PATCH /api/devices/:uuid/` - Promises to update a device
     * @param {string} uuid - The universally unique identifier of the device
     * @param {string} name - The name of the device
     */
    DevicesAPI.prototype.updateDevice = function (uuid, name) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push(encodeURIComponent(uuid));
                return [2 /*return*/, this.patch({ name: name })];
            });
        });
    };
    /**
     * `DELETE /api/devices/:uuid/` - Promise to delete a device
     * @param {string} uuid - The universally unique identifier of the device
     */
    DevicesAPI.prototype.deleteDevice = function (uuid) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push(encodeURIComponent(uuid));
                return [2 /*return*/, this.delete()];
            });
        });
    };
    return DevicesAPI;
}(APIRequest_1.APIRequest));
exports.DevicesAPI = DevicesAPI;
