"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var APIRequest_1 = require("../utils/APIRequest");
/**
 * @api public
 * ListsAPI - Provides methods to interact with the Lists API
 */
var ListsAPI = /** @class */ (function (_super) {
    tslib_1.__extends(ListsAPI, _super);
    function ListsAPI(opts) {
        return _super.call(this, opts) || this;
    }
    /**
     * `GET /api/lists/` - promises to retrieve all lists
     * @returns - an array of lists
     */
    ListsAPI.prototype.getLists = function () {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                return [2 /*return*/, this.get()];
            });
        });
    };
    /**
     * `PUT /api/lists/` - promises to create a new circle
     * @param {ICreateList} opts - The circle's properties
     * @returns - the circle
     */
    ListsAPI.prototype.createList = function (opts) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            var body;
            return tslib_1.__generator(this, function (_a) {
                body = {
                    name: opts.name
                };
                if (opts.emojiId !== undefined) {
                    body.emoji_id = opts.emojiId;
                }
                return [2 /*return*/, this.put(body)];
            });
        });
    };
    /**
     * `PATCH /api/lists/:id/` - promises to update a circle
     * @param {number} id - The ID of the circle
     * @param {IUpdateList} - The circle's new properties
     * @returns - the updated circle
     */
    ListsAPI.prototype.updateList = function (id, opts) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            var body;
            return tslib_1.__generator(this, function (_a) {
                this._paths.push(id.toString());
                body = {
                    name: opts.name,
                };
                if (opts.emojiId !== undefined) {
                    body.emoji_id = opts.emojiId;
                }
                if (opts.usernames && opts.usernames.length) {
                    body.usernames = opts.usernames;
                }
                return [2 /*return*/, this.patch(body)];
            });
        });
    };
    /**
     * `DELETE /api/lists/:id/` - promises to delete a circle
     * @param {number} id - The ID of the circle
     */
    ListsAPI.prototype.deleteList = function (id) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push(id.toString());
                return [2 /*return*/, this.delete()];
            });
        });
    };
    /**
     * `GET /api/lists/:id/` - promises to get a circle
     * @param {number} id - The ID of the circle
     * @returns - the requested circle
     */
    ListsAPI.prototype.getList = function (id) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push(id.toString());
                return [2 /*return*/, this.get()];
            });
        });
    };
    /**
     * `POST /api/lists/name-check/` - promises to check if a circle name is available
     * @param {string} name - The desired name
     */
    ListsAPI.prototype.checkNameIsAvailable = function (name) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push('name-check');
                return [2 /*return*/, this.post({ name: name })];
            });
        });
    };
    return ListsAPI;
}(APIRequest_1.APIRequest));
exports.ListsAPI = ListsAPI;
