import { APIRequest } from "../utils/APIRequest";
import { RequestOpts, LimitationParams } from '../typings';
/**
 * @api public
 * NotificationsAPI - Provides methods to interact with the Notifications API
 */
declare class NotificationsAPI extends APIRequest {
    constructor(opts: RequestOpts);
    /**
     * `GET /api/notifications/` - promises to retrieve the user's notifications
     * @param {LimitationParams} opts - The limitation rules
     */
    getNotifications(opts: LimitationParams): Promise<any>;
    /**
     * `POST /api/notifications/read/` - promises to mark notifications as read
     * @param {LimitationParams} opts - The limitation rules
     */
    readNotifications(opts: LimitationParams): Promise<any>;
    /**
     * `DELETE /api/notifications/` - promises to delete all notifications
     */
    deleteNotifications(): Promise<any>;
    /**
     * `DELETE /api/notifications/:id/` - promises to delete a notification
     * @param {number} id - The ID of the notification
     */
    deleteNotification(id: number): Promise<any>;
    /**
     * `GET /api/notifications/:id/` - promises to get a notification
     * @param {number} id - The ID of the notification
     */
    getNotification(id: number): Promise<any>;
    /**
     * `POST /api/notifications/:id/` - promises to mark a notification as read
     * @param {number} id - The ID of the notification
     */
    readNotification(id: number): Promise<any>;
}
export { NotificationsAPI };
