"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var APIRequest_1 = require("../utils/APIRequest");
var FileObject_1 = require("../utils/FileObject");
var PostsAPI = /** @class */ (function (_super) {
    tslib_1.__extends(PostsAPI, _super);
    function PostsAPI(opts) {
        return _super.call(this, opts) || this;
    }
    PostsAPI.prototype.getTimelinePosts = function (opts) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                if (opts.listIds && opts.listIds.length) {
                    this._params['list_id'] = opts.listIds.join(',');
                }
                if (opts.circleIds && opts.circleIds.length) {
                    this._params['circle_id'] = opts.circleIds.join(',');
                }
                if (opts.count !== undefined) {
                    this._params['count'] = opts.count;
                }
                if (opts.maxId !== undefined) {
                    this._params['max_id'] = opts.maxId;
                }
                if (opts.username) {
                    this._params['username'] = opts.username;
                }
                return [2 /*return*/, this.get()];
            });
        });
    };
    PostsAPI.prototype.createPost = function (opts) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            var payload;
            return tslib_1.__generator(this, function (_a) {
                payload = {};
                if (opts.image) {
                    payload['image'] = new FileObject_1.FileObject(opts.image);
                }
                if (opts.video) {
                    payload['video'] = new FileObject_1.FileObject(opts.video);
                }
                if (opts.text) {
                    payload['text'] = opts.text;
                }
                if (opts.circleIds && opts.circleIds.length) {
                    payload['circle_id'] = opts.circleIds.join(',');
                }
                return [2 /*return*/, this.putFormdata(payload)];
            });
        });
    };
    PostsAPI.prototype.getTrendingPosts = function () {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push('trending');
                return [2 /*return*/, this.get()];
            });
        });
    };
    PostsAPI.prototype.editPost = function (opts) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            var payload;
            return tslib_1.__generator(this, function (_a) {
                this._paths.push(encodeURIComponent(opts.uuid));
                payload = {
                    post_uuid: opts.uuid
                };
                if (opts.text) {
                    payload['text'] = opts.text;
                }
                return [2 /*return*/, this.patchFormdata(payload)];
            });
        });
    };
    PostsAPI.prototype.getPostWithUuid = function (uuid) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push(encodeURIComponent(uuid));
                return [2 /*return*/, this.get()];
            });
        });
    };
    PostsAPI.prototype.deletePostWithUuid = function (uuid) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push(encodeURIComponent(uuid));
                return [2 /*return*/, this.delete()];
            });
        });
    };
    PostsAPI.prototype.getCommentsForPost = function (uuid, opts) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push(encodeURIComponent(uuid), 'comments');
                if (opts.countMax !== undefined) {
                    this._params.count_max = opts.countMax;
                }
                if (opts.countMin !== undefined) {
                    this._params.count_min = opts.countMin;
                }
                if (opts.maxId !== undefined) {
                    this._params.max_id = opts.maxId;
                }
                if (opts.minId !== undefined) {
                    this._params.min_id = opts.minId;
                }
                if (opts.sort) {
                    this._params.sort = opts.sort;
                }
                return [2 /*return*/, this.get()];
            });
        });
    };
    PostsAPI.prototype.getRepliesForPostComment = function (postUuid, postCommentId, opts) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push(encodeURIComponent(postUuid), 'comments', postCommentId.toString());
                if (opts.countMax !== undefined) {
                    this._params.count_max = opts.countMax;
                }
                if (opts.countMin !== undefined) {
                    this._params.count_min = opts.countMin;
                }
                if (opts.maxId !== undefined) {
                    this._params.max_id = opts.maxId;
                }
                if (opts.minId !== undefined) {
                    this._params.min_id = opts.minId;
                }
                if (opts.sort) {
                    this._params.sort = opts.sort;
                }
                return [2 /*return*/, this.get()];
            });
        });
    };
    PostsAPI.prototype.commentOnPost = function (uuid, text) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push(encodeURIComponent(uuid), 'comments');
                return [2 /*return*/, this.put({ text: text })];
            });
        });
    };
    PostsAPI.prototype.editPostComment = function (postUuid, commentId, text) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push(encodeURIComponent(postUuid), 'comments', commentId.toString());
                return [2 /*return*/, this.patch({ text: text })];
            });
        });
    };
    PostsAPI.prototype.replyPostComment = function (postUuid, commentId, text) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push(encodeURIComponent(postUuid), 'comments', commentId.toString(), 'replies');
                return [2 /*return*/, this.put({ text: text })];
            });
        });
    };
    PostsAPI.prototype.deletePostComment = function (postUuid, commentId) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push(encodeURIComponent(postUuid), 'comments', commentId.toString());
                return [2 /*return*/, this.delete()];
            });
        });
    };
    PostsAPI.prototype.getReactionsForPost = function (uuid, opts) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push(encodeURIComponent(uuid), 'reactions');
                if (opts.count !== undefined) {
                    this._params.count = opts.count;
                }
                if (opts.maxId !== undefined) {
                    this._params.max_id = opts.maxId;
                }
                if (opts.emojiId !== undefined) {
                    this._params.emoji_id = opts.emojiId;
                }
                return [2 /*return*/, this.get()];
            });
        });
    };
    PostsAPI.prototype.getReactionsEmojiCountForPost = function (uuid) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push(encodeURIComponent(uuid), 'reactions', 'emoji-count');
                return [2 /*return*/, this.get()];
            });
        });
    };
    PostsAPI.prototype.reactToPost = function (uuid, emojiId) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push(encodeURIComponent(uuid), 'reactions');
                return [2 /*return*/, this.put({ emoji_id: emojiId })];
            });
        });
    };
    PostsAPI.prototype.deletePostReaction = function (postUuid, reactionId) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push(encodeURIComponent(postUuid), 'reactions', reactionId.toString());
                return [2 /*return*/, this.delete()];
            });
        });
    };
    PostsAPI.prototype.getReactionsForPostComment = function (postUuid, commentId, opts) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push(encodeURIComponent(postUuid), 'comments', commentId.toString(), 'reactions');
                if (opts.count !== undefined) {
                    this._params.count = opts.count;
                }
                if (opts.maxId !== undefined) {
                    this._params.max_id = opts.maxId;
                }
                if (opts.emojiId !== undefined) {
                    this._params.emoji_id = opts.emojiId;
                }
                return [2 /*return*/, this.get()];
            });
        });
    };
    PostsAPI.prototype.getReactionsEmojiCountForPostComment = function (postUuid, commentId) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push(encodeURIComponent(postUuid), 'comments', commentId.toString(), 'reactions', 'emoji-count');
                return [2 /*return*/, this.get()];
            });
        });
    };
    PostsAPI.prototype.reactToPostComment = function (postUuid, commentId, emojiId) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push(encodeURIComponent(postUuid), 'comments', commentId.toString(), 'reactions');
                return [2 /*return*/, this.put({ emoji_id: emojiId })];
            });
        });
    };
    PostsAPI.prototype.deletePostCommentReaction = function (postUuid, commentId, reactionId) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push(encodeURIComponent(postUuid), 'comments', commentId.toString(), 'reactions', reactionId.toString());
                return [2 /*return*/, this.delete()];
            });
        });
    };
    PostsAPI.prototype.mutePostComment = function (postUuid, commentId) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push(encodeURIComponent(postUuid), 'comments', commentId.toString(), 'notifications', 'mute');
                return [2 /*return*/, this.post({})];
            });
        });
    };
    PostsAPI.prototype.unmutePostComment = function (postUuid, commentId) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push(encodeURIComponent(postUuid), 'comments', commentId.toString(), 'notifications', 'unmute');
                return [2 /*return*/, this.post({})];
            });
        });
    };
    PostsAPI.prototype.mutePost = function (uuid) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push(encodeURIComponent(uuid), 'notifications', 'mute');
                return [2 /*return*/, this.post({})];
            });
        });
    };
    PostsAPI.prototype.unmutePost = function (uuid) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push(encodeURIComponent(uuid), 'notifications', 'unmute');
                return [2 /*return*/, this.post({})];
            });
        });
    };
    PostsAPI.prototype.disableCommentsForPost = function (uuid) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push(encodeURIComponent(uuid), 'comments', 'disable');
                return [2 /*return*/, this.post({})];
            });
        });
    };
    PostsAPI.prototype.enableCommentsForPost = function (uuid) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push(encodeURIComponent(uuid), 'comments', 'enable');
                return [2 /*return*/, this.post({})];
            });
        });
    };
    PostsAPI.prototype.openPost = function (uuid) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push(encodeURIComponent(uuid), 'open');
                return [2 /*return*/, this.post({})];
            });
        });
    };
    PostsAPI.prototype.closePost = function (uuid) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push(encodeURIComponent(uuid), 'close');
                return [2 /*return*/, this.post({})];
            });
        });
    };
    PostsAPI.prototype.getReactionEmojiGroups = function () {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push('emojis/groups');
                return [2 /*return*/, this.get()];
            });
        });
    };
    PostsAPI.prototype.reportPost = function (opts) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            var body;
            return tslib_1.__generator(this, function (_a) {
                this._paths.push(encodeURIComponent(opts.postUuid), 'report');
                body = {
                    category_id: opts.moderationCategoryId.toString()
                };
                if (opts.description) {
                    body.description = opts.description;
                }
                return [2 /*return*/, this.post(body)];
            });
        });
    };
    PostsAPI.prototype.reportPostComment = function (opts) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            var body;
            return tslib_1.__generator(this, function (_a) {
                this._paths.push(encodeURIComponent(opts.postUuid), 'comments', opts.commentId.toString(), 'report');
                body = {
                    category_id: opts.moderationCategoryId.toString()
                };
                if (opts.description) {
                    body.description = opts.description;
                }
                return [2 /*return*/, this.post(body)];
            });
        });
    };
    PostsAPI.prototype.translatePost = function (uuid) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push(encodeURIComponent(uuid), 'translate');
                return [2 /*return*/, this.post({})];
            });
        });
    };
    PostsAPI.prototype.translatePostComment = function (postUuid, commentId) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push(encodeURIComponent(postUuid), 'comments', commentId.toString(), 'translate');
                return [2 /*return*/, this.post({})];
            });
        });
    };
    PostsAPI.prototype.getPostParticipants = function (opts) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push(encodeURIComponent(opts.postUuid), 'participants');
                if (opts.count !== undefined) {
                    this._params.count = opts.count;
                }
                return [2 /*return*/, this.get()];
            });
        });
    };
    PostsAPI.prototype.searchPostParticipants = function (opts) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push(encodeURIComponent(opts.postUuid), 'participants', 'search');
                this._params.query = opts.query;
                if (opts.count !== undefined) {
                    this._params.count = opts.count;
                }
                return [2 /*return*/, this.get()];
            });
        });
    };
    return PostsAPI;
}(APIRequest_1.APIRequest));
exports.PostsAPI = PostsAPI;
