import { APIRequest } from '../utils/APIRequest';
import { RequestOpts } from '../typings';
/**
 * @api public
 * UserInvitesAPI - Provides methods to interact with the User Invites API
 */
declare class UserInvitesAPI extends APIRequest {
    constructor(opts: RequestOpts);
    /**
     * `PUT /api/invites/` - promises to create an invite
     * @param {string} nickname - A nickname for the notification
     */
    create(nickname: string): Promise<any>;
    /**
     * `PATCH /api/invites/` - promises to update a notification's nickname
     * @param {string} id - The ID of the notification
     * @param {string} nickname - The new nickname
     */
    update(id: number, nickname: string): Promise<any>;
    /**
     * `GET /api/invites/` - promises to retrieve a list of all invites
     * @param {number} offset
     * @param {number} count
     * @param {boolean} pending
     */
    getUserInvites(offset?: number | null, count?: number | null, pending?: boolean | null): Promise<any>;
    /**
     * `GET /api/invites/search/` - promises to search between the user invites
     * @param {string} query
     * @param {number} count
     * @param {boolean} pending
     */
    searchUserInvite(query: string, count?: number | null, pending?: boolean | null): Promise<any>;
    /**
     * `DELETE /api/invites/:id/` - promises to delete an invite
     * @param {number} id - The ID of the invite
     */
    deleteUserInvite(id: number): Promise<any>;
    /**
     * `POST /api/invites/:id/email/` - promises to sent an email with the invitation
     * @param {number} id - The ID of the invite
     * @param {string} email - The email to which the invite will be sent
     */
    email(id: number, email: string): Promise<any>;
}
export { UserInvitesAPI };
