"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var APIRequest_1 = require("../utils/APIRequest");
/**
 * @api public
 * UserInvitesAPI - Provides methods to interact with the User Invites API
 */
var UserInvitesAPI = /** @class */ (function (_super) {
    tslib_1.__extends(UserInvitesAPI, _super);
    function UserInvitesAPI(opts) {
        return _super.call(this, opts) || this;
    }
    /**
     * `PUT /api/invites/` - promises to create an invite
     * @param {string} nickname - A nickname for the notification
     */
    UserInvitesAPI.prototype.create = function (nickname) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            var body;
            return tslib_1.__generator(this, function (_a) {
                body = {};
                if (nickname) {
                    body['nickname'] = nickname;
                }
                return [2 /*return*/, this.putFormdata(body)];
            });
        });
    };
    /**
     * `PATCH /api/invites/` - promises to update a notification's nickname
     * @param {string} id - The ID of the notification
     * @param {string} nickname - The new nickname
     */
    UserInvitesAPI.prototype.update = function (id, nickname) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push(id.toString());
                return [2 /*return*/, this.patchFormdata({ nickname: nickname })];
            });
        });
    };
    /**
     * `GET /api/invites/` - promises to retrieve a list of all invites
     * @param {number} offset
     * @param {number} count
     * @param {boolean} pending
     */
    UserInvitesAPI.prototype.getUserInvites = function (offset, count, pending) {
        if (offset === void 0) { offset = null; }
        if (count === void 0) { count = null; }
        if (pending === void 0) { pending = null; }
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                if (offset !== null) {
                    this._params['offset'] = offset;
                }
                if (count !== null) {
                    this._params['count'] = count;
                }
                if (pending !== null) {
                    this._params['pending'] = pending;
                }
                return [2 /*return*/, this.get()];
            });
        });
    };
    /**
     * `GET /api/invites/search/` - promises to search between the user invites
     * @param {string} query
     * @param {number} count
     * @param {boolean} pending
     */
    UserInvitesAPI.prototype.searchUserInvite = function (query, count, pending) {
        if (count === void 0) { count = null; }
        if (pending === void 0) { pending = null; }
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push('search');
                this._params['query'] = encodeURIComponent(query);
                if (count !== null) {
                    this._params['count'] = count;
                }
                if (pending !== null) {
                    this._params['pending'] = pending;
                }
                return [2 /*return*/, this.get()];
            });
        });
    };
    /**
     * `DELETE /api/invites/:id/` - promises to delete an invite
     * @param {number} id - The ID of the invite
     */
    UserInvitesAPI.prototype.deleteUserInvite = function (id) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push(id.toString());
                return [2 /*return*/, this.delete()];
            });
        });
    };
    /**
     * `POST /api/invites/:id/email/` - promises to sent an email with the invitation
     * @param {number} id - The ID of the invite
     * @param {string} email - The email to which the invite will be sent
     */
    UserInvitesAPI.prototype.email = function (id, email) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            return tslib_1.__generator(this, function (_a) {
                this._paths.push(id.toString(), 'email');
                return [2 /*return*/, this.post({ email: email })];
            });
        });
    };
    return UserInvitesAPI;
}(APIRequest_1.APIRequest));
exports.UserInvitesAPI = UserInvitesAPI;
