import { RequestOpts, IRequestStrategy, RequestParams } from '../typings';
import { Client } from '../Okuna';
import 'isomorphic-form-data';
/**
 * @api
 */
declare class APIRequest {
    /**
     * Defines an API request.
     *
     * @param {RequestOpts} opts
     */
    protected _okuna: Client;
    protected _endpoint: string;
    protected _url: string;
    protected _paths: string[];
    protected _params: RequestParams;
    protected _headers: object;
    protected _api: IRequestStrategy;
    requiresToken: boolean;
    constructor(opts: RequestOpts);
    /**
     * generateHeaders()
     * A function used to generate the headers that need to be
     * passed to the request performee.
     * @returns {object}
     */
    generateHeaders(contentType?: string | null): object;
    /**
     * constructFormdata()
     * Constructs a FormData instance from an object.
     * @param {object} opts - the object to generate the FormData from
     * @returns {FormData}
     */
    _constructFormdata(opts?: object | null): FormData;
    /**
     * get()
     * GET request
     * @returns {Promise<any>}
     */
    protected get(): Promise<any>;
    /**
     * put()
     * PUT request
     * @param {object} body - Request body
     */
    protected put(body: object): Promise<any>;
    /**
     * post()
     * POST request
     * @param {object} body - Request body
     */
    protected post(body: object): Promise<any>;
    /**
     * patch()
     * PATCH request
     * @param {object} body - Request body
     */
    protected patch(body: object): Promise<any>;
    /**
     * delete()
     * DELETE request
     * @returns {Promise<any>}
     */
    protected delete(): Promise<any>;
    /**
     * putFormdata()
     * PUT request (multipart/form-data, application/x-www-form-urlencoded)
     */
    protected putFormdata(body: object): Promise<any>;
    /**
     * postFormdata()
     * POST request (multipart/form-data, application/x-www-form-urlencoded)
     */
    protected postFormdata(body: object): Promise<any>;
    /**
     * patchFormdata()
     * PATCH request (multipart/form-data, application/x-www-form-urlencoded)
     */
    protected patchFormdata(body: object): Promise<any>;
}
export { APIRequest };
