"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * buildUrl()
 * Creates a fetchable URL
 * @param {string} apiUrl - The URL address of the Okuna API server
 * @param {string[]} paths - An array containing additional paths for the endpoint
 * @param {object} params - Key-value properties to append to the URL (mainly used for GET requests)
 * @returns {string} - The final URL to fetch
 */
var buildUrl = function (apiUrl, paths, params) {
    if (apiUrl.slice(-1) === '/') {
        apiUrl = apiUrl.slice(0, -1);
    }
    var _paths = paths.join('/');
    var _params = Object.keys(params)
        .map(function (key) { return key + "=" + params[key]; })
        .join('&');
    return _params
        ? "" + apiUrl + _paths + "/?" + _params
        : "" + apiUrl + _paths + "/";
};
exports.default = buildUrl;
