"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * encodeParent() - Encodes a parent key (nested objects)
 * @param {string} input - The parent key
 * @returns {string} - The encoded parent key
 */
var encodeParent = function (input) {
    return encodeURIComponent(input)
        .replace(/%5B/g, '[')
        .replace(/%5D/g, ']');
};
/**
 * queryString() - Builds a querystring from an object
 * @param {object} obj - The object to convert to a querystring
 * @param {object | null} parent - The current parent key
 */
var queryString = function (obj, parent) {
    if (parent === void 0) { parent = null; }
    return Object.keys(obj).map(function (key) {
        var value = obj[key];
        if (typeof value === 'object') {
            return queryString(value, (parent ? encodeParent(parent) + "[" + encodeURIComponent(key) + "]" : key));
        }
        return parent
            ? parent + "[" + encodeURIComponent(key) + "]=" + encodeURIComponent(value)
            : encodeURIComponent(key) + "=" + encodeURIComponent(value);
    })
        .join('&');
};
exports.default = queryString;
